@@ -57,6 +57,60 @@
 
 /*) There are methods which are using VPath to get schema and host
  (*/
+static VFSManager * _sManagerOfVFS = NULL;
+
+rc_t CC
+_InitVFSManager ()
+{
+    rc_t RCt;
+    VFSManager * Manager;
+
+    RCt = 0;
+    Manager = NULL;
+
+    if ( _sManagerOfVFS != NULL ) {
+        return 0;
+    }
+
+    RCt = VFSManagerMake ( & Manager );
+    if ( RCt == 0 ) {
+        _sManagerOfVFS = Manager;
+    }
+
+    return RCt;
+}   /* _InitVFSManager () */
+
+rc_t CC
+_GetVFSManager ( VFSManager ** Manager )
+{
+    rc_t RCt = 0;
+
+    * Manager = NULL;
+
+    if ( _sManagerOfVFS == NULL ) {
+        RCt = _InitVFSManager ();
+    }
+
+    * Manager = _sManagerOfVFS;
+
+    return RCt;
+}   /* _GetVFSManager () */
+
+rc_t CC
+_DisposeVFSManager ()
+{
+    VFSManager * Manager = _sManagerOfVFS;
+
+    _sManagerOfVFS = NULL;
+
+    if ( Manager == NULL ) {
+        return 0;
+    }
+
+    ReleaseComplain (VFSManagerRelease, Manager );
+
+    return 0;
+}   /* _DisposeVFSManager () */
 
 typedef rc_t ( CC * _PathReader ) (
                                 const VPath * self,
@@ -89,7 +143,7 @@ _ReadSomething (
 
     * Buffer = 0;
 
-    RCt = VFSManagerMake ( & Manager );
+    RCt = _GetVFSManager ( & Manager );
     if ( RCt == 0 ) {
         RCt = VFSManagerMakePath ( Manager, & ThePath, Path );
         if ( RCt == 0 ) {
@@ -97,8 +151,6 @@ _ReadSomething (
 
             ReleaseComplain ( VPathRelease, ThePath );
         }
-
-        ReleaseComplain ( VFSManagerRelease, Manager );
     }
 
     return RCt;
@@ -872,6 +924,13 @@ RemoteCacheCreate ()
     RCt = 0;
     * Buffer = 0;
 
+    RCt = _InitVFSManager ();
+    if ( RCt != 0 ) {
+        LOGMSG( klogErr, "[RemoteCache] can not create instance of VFSManater\n" );
+        return RC ( rcExe, rcPath, rcInitializing, rcSelf, rcNull );
+    }
+
+
     if ( RemoteCacheIsDisklessMode () ) {
         LOGMSG( klogInfo, "[RemoteCache] entering diskless mode\n" );
         return 0;
@@ -999,6 +1058,8 @@ RmOutMsg ( "[KLockRelease] [%p] [ %d]\n", ( void * ) _CacheLock, __LINE__ );
     * _CacheRoot = 0;
     _PCacheRoot = NULL;
 
+    _DisposeVFSManager ();
+
     return RCt;
 }   /* RemoteCacheDispose () */
 
@@ -1525,6 +1586,7 @@ RmOutMsg ( "  |<-- Cache Entry [%s]\n", self -> Path );
                                 & HttpFile,
                                 NULL, /* no open connections */
                                 0x01010000,
+                                "%s",
                                 self -> Url
                                 );
     if ( RCt == 0 ) {
@@ -1534,7 +1596,7 @@ RmOutMsg ( "  |<-- Cache Entry [%s]\n", self -> Path );
         else {
             RCt = KDirectoryNativeDir ( & Directory );
             if ( RCt == 0 ) {
-                RCt = KDirectoryMakeCacheTee (
+                RCt = KDirectoryMakeCacheTeePromote (
                                     Directory,
                                     & TeeFile,
                                     HttpFile,
@@ -1819,7 +1881,12 @@ _RCacheEntryDoRead (
     }
 
     if ( SizeToRead == 0 ) {
-        return RC ( rcExe, rcFile, rcReading, rcParam, rcInvalid );
+        * NumReaded = 0;
+
+        return 0;
+        /* Bad decision
+            return RC ( rcExe, rcFile, rcReading, rcParam, rcInvalid );
+        */
     }
 
         /*)  Here we are locking
@@ -2022,6 +2089,7 @@ ReadHttpFileToMemory (
                                 & File,
                                 NULL,   /* no open connections */
                                 0x01010000,
+                                "%s",
                                 Url
                                 );
     if ( RCt == 0 ) {
@@ -2094,6 +2162,7 @@ ExecuteCGI ( const char * CGICommand )
                                 & File,
                                 NULL,   /* no open connections */
                                 0x01010000,
+                                "%s",
                                 CGICommand
                                 );
     if ( RCt == 0 ) {
